@@ -3,6 +3,7 @@ import numpy as np
 import pandas as pd
 import torch.nn as nn
 from tcrpeg.model import TCRpeg_model, TCRpeg_vj_model
+# from model import TCRpeg_model,TCRpeg_vj_model
 from tqdm import tqdm
 import time
 from datetime import datetime
@@ -101,8 +102,11 @@ class TCRpeg:
         self.evaluate = True if evaluate != 0 else False
         if load_data:
             if vj:
-                #####remember to add 
-                self.aas_seqs_train,self.vs_train,self.js_train = self.load_data(path_train,vj=True)
+                if type(path_train) is not str:
+                    self.aas_seqs_train = np.array([x[0] for x in path_train])
+                    self.vs_train,self.js_train=[x[1] for x in path_train],[x[2] for x in path_train]
+                else :
+                    self.aas_seqs_train,self.vs_train,self.js_train = self.load_data(path_train,vj=True)
                 self.vs_train,self.js_train = self.gene2embs(self.vs_train,'v'),self.gene2embs(self.js_train,'j')
             else :
                 if type(path_train) is not str:
@@ -110,11 +114,19 @@ class TCRpeg:
                 else :
                     self.aas_seqs_train = self.load_data(path_train)
             if self.evaluate:
+                #remember to add!!
                 if vj is not None:
-                    self.aas_seqs_test,self.vs_test,self.js_test = self.load_data(path_test)
+                    if type(path_train) is not str:
+                        self.aas_seqs_test = np.array([x[0] for x in path_test])
+                        self.vs_test,self.js_test=[x[1] for x in path_test],[x[2] for x in path_test]
+                    else :
+                        self.aas_seqs_test,self.vs_test,self.js_test = self.load_data(path_test)
                     self.vs_test,self.js_test = self.gene2embs(self.vs_test,'v'),self.gene2embs(self.js_test,'j')
                 else :
-                    self.aas_seqs_test = self.load_data(path_test)
+                    if type(path_test) is not str:
+                        self.aas_seqs_test = path_test
+                    else :
+                        self.aas_seqs_test = self.load_data(path_test)
             print("Have loaded the data, total training seqs :", len(self.aas_seqs_train))
 
     def aas2embs(self, seqs):
@@ -197,8 +209,11 @@ class TCRpeg:
                 self.hidden_size,
                 self.dropout,
                 self.max_length,
-                num_layers=self.num_layers           
+                num_layers=self.num_layers  ,
+                num_v = len(self.vs_list),
+                num_j = len(self.js_list)
             )
+            self.vj=True
         else :
             model = TCRpeg_model(
                 self.embedding_layer,
@@ -207,6 +222,7 @@ class TCRpeg:
                 dropout=self.dropout,
                 num_layers=self.num_layers
                 )
+            self.vj=False
         model.train()
         if load:
             model.load_state_dict(torch.load(path))
@@ -671,7 +687,7 @@ class TCRpeg:
                     f.write(s + ',' + vs_whole[i] + ',' + js_whole[i] + "\n")
         return [seqs,vs_whole,js_whole]
 
-    def get_embedding(self,seqs,last_layer=False,vj=False):
+    def get_embedding(self,seqs,last_layer=False):
         '''
         Get the embedding of CDR3 sequences
         @seqs: a list containing the CDR3 sequences
@@ -685,7 +701,7 @@ class TCRpeg:
         with torch.no_grad():
             inputs,targets,lengths = self.aas2embs(seqs)
             inputs,targets,lengths = torch.LongTensor(inputs).to(self.device),torch.LongTensor(targets).to(self.device),torch.LongTensor(lengths).to(self.device)
-            if vj:
+            if self.vj:                
                 _,_,_,embedding = self.model(inputs,lengths,True)
             else :
                 _,embedding= self.model(inputs,lengths,True)
@@ -696,107 +712,3 @@ class TCRpeg:
             #embedding = embedding.view(batch_size,-1)
         return embedding.detach().cpu().numpy()
 
-
-if __name__ == "__main__":
-    parser = argparse.ArgumentParser(description="")
-    parser.add_argument("--beta", type=float)
-    parser.add_argument("--epochs", type=int)
-    parser.add_argument("--batch_size", type=int)
-    parser.add_argument("--info", type=str, default=None)
-    parser.add_argument("--model_name", type=str, default=None)
-    parser.add_argument(
-        "--bi_encode", type=int, default=0, help="only 1 can intrigue bi encoding"
-    )
-    parser.add_argument("--dropout", type=float, default=0)
-    parser.add_argument("--num_layers", type=int, default=1)
-    parser.add_argument("--latent_size", type=int, default=30)
-    parser.add_argument("--hidden_size", type=int, default=50)
-    # evaluate=1,path_train=None,path_test=None
-    parser.add_argument("--evaluate", type=int, default=1)
-    parser.add_argument("--path_to_train", type=str, default=None)
-    parser.add_argument("--path_test", type=str, default=None)
-    parser.add_argument("--pre_train_path", type=str, default=None)
-    parser.add_argument("--record_path", type=str, default=None,help='this is for record the gerated seqs')
-    parser.add_argument("--num_to_gen", type=int, default=0)
-    parser.add_argument('--fine_tune',type=int,default=0)
-    parser.add_argument('--fine_tune_file_path',type=str,default=None)
-    parser.add_argument('--vj_model',type=int,default=0)
-
-    args = parser.parse_args()
-    fine_tune = True if args.fine_tune != 0 else False
-    torch.manual_seed(0)
-    np.random.seed(0)
-    vj_model = True if args.vj_model != 0 else False
-    if args.num_to_gen != 0 or fine_tune:
-        load = False
-    else :
-        load = True
-
-    if vj_model:
-        vs = ['TRBV10-1','TRBV10-2','TRBV10-3','TRBV11-1','TRBV11-2','TRBV11-3','TRBV12-5', 'TRBV13', 'TRBV14', 'TRBV15', 
-        'TRBV16', 'TRBV18','TRBV19','TRBV2', 'TRBV20-1', 'TRBV25-1', 'TRBV27', 'TRBV28', 'TRBV29-1', 'TRBV3-1', 'TRBV30',
-'TRBV4-1', 'TRBV4-2','TRBV4-3',
- 'TRBV5-1', 'TRBV5-4', 'TRBV5-5', 'TRBV5-6', 'TRBV5-8','TRBV6-1', 'TRBV6-4', 'TRBV6-5', 'TRBV6-6','TRBV6-8', 'TRBV6-9', 'TRBV7-2', 'TRBV7-3',
-  'TRBV7-4', 'TRBV7-6', 'TRBV7-7', 'TRBV7-8', 'TRBV7-9', 'TRBV9']
-        js = ['TRBJ1-1', 'TRBJ1-2', 'TRBJ1-3','TRBJ1-4', 'TRBJ1-5', 'TRBJ1-6','TRBJ2-1', 'TRBJ2-2', 'TRBJ2-3', 'TRBJ2-4', 'TRBJ2-6', 'TRBJ2-7']
-        nlp_model = vae_nlp(
-        beta=args.beta,
-        embedding_size=32,
-        hidden_size=args.hidden_size,
-        latent_size=args.latent_size,
-        dropout=args.dropout,
-        num_layers=args.num_layers,
-        bi_encode=True if args.bi_encode == 1 else False,
-        evaluate=args.evaluate,
-        load_data = load,
-        path_train=args.path_to_train,
-        path_test=args.path_test,
-        vs_dic=vs,
-        js_dic = js
-    )
-        if args.num_to_gen != 0:
-            #begin generating
-            nlp_model.create_model(load=True, path=args.pre_train_path, only_decoder=True,vj_decoder=True)
-            seqs,vs,js = nlp_model.generate_decoder_batch_vj(args.num_to_gen, 
-                                            args.batch_size,record_path=args.record_path)
-            exit()
-    else :     
-        nlp_model = vae_nlp(
-            beta=args.beta,
-            embedding_size=32,
-            hidden_size=args.hidden_size,
-            latent_size=args.latent_size,
-            dropout=args.dropout,
-            num_layers=args.num_layers,
-            bi_encode=True if args.bi_encode == 1 else False,
-            evaluate=args.evaluate,
-            load_data = load,
-            path_train=args.path_to_train,
-            path_test=args.path_test,
-        )
-
-    if vj_model:
-        nlp_model.create_model(only_decoder=True,vj_decoder=True)
-        nlp_model.train_decoder_vj(args.epochs, args.batch_size, 1e-4, args.info, args.model_name)
-        exit()
-
-    if fine_tune:
-        nlp_model.create_model(load=True, path=args.pre_train_path, only_decoder=True)
-        nlp_model.aas_seqs_train = nlp_model.load_data(args.fine_tune_file_path, True)
-        nlp_model.train_decoder(
-            args.epochs, args.batch_size, 1e-4, args.info, args.model_name
-        )
-        exit()
-
-    if args.pre_train_path is None:
-        nlp_model.create_model(only_decoder=True)
-        nlp_model.train_decoder(
-            args.epochs, args.batch_size, 1e-3, args.info, args.model_name
-        )
-        #lr rate original is 5e-4
-    else:
-        assert args.record_path is not None
-        nlp_model.create_model(load=True, path=args.pre_train_path, only_decoder=True)
-        #nlp_model.generate_decoder(args.num_to_gen, args.record_path)
-        seqs = nlp_model.generate_decoder_batch(args.num_to_gen, args.batch_size,record_path=args.record_path)
-        #print(seqs[:10])
